@@ -73,10 +73,6 @@ class Tier(object):
 
     def to_plot(self, start_time=None, end_time=None):
         """Plot the points of the Tier from between two time points. If the time points are not specified, start time and end time are used. To change related parameters, use parameters."""
-        import seaborn as sns
-        from matplotlib import pyplot as plt
-
-        plt.figure(figsize=parameters['to_plot.size'])
 
         if start_time == None:
             start_time = self.start_time
@@ -88,7 +84,20 @@ class Tier(object):
         this_df = df[df.time >= start_time]
         this_df = this_df[this_df.time <= end_time]
 
-        plot = sns.scatterplot(x='time', y='value', data=this_df)
+        if parameters['to_plot.package'] == 'matplotlib':
+            import seaborn as sns
+            from matplotlib import pyplot as plt
+
+            plt.figure(figsize=parameters['to_plot.size'])
+
+            plot = sns.scatterplot(x='time', y='value', data=this_df)
+
+        if parameters['to_plot.package'] == 'plotly':
+            import plotly.express as px
+
+            plot = px.scatter(this_df, x="time", y="value")
+            plot.update_layout(xaxis=dict(rangeslider=dict(visible=True),
+                                          type="linear"))
 
         return plot
 
