@@ -28,6 +28,13 @@ class Parameter(dict):
 
             if key == 'write_to_file.replace' and value:
                 super().__setitem__('write_to_file.duplicate', False)
+            
+            if key == 'to_plot.package' and value == 'matplotlib':
+                super().__setitem__('to_plot.size', (15, 10))
+
+            if key == 'to_plot.package' and value == 'plotly':
+                super().__setitem__('to_plot.size', None)
+            
 
             super().__setitem__(key, value)
 
@@ -38,6 +45,7 @@ parameters = Parameter(
         'write_to_file.duplicate': False,
         'write_to_file.duplicated_name_extension': 'modified',
         'points.ignore_missing_point': False,
+        'to_plot.package': 'matplotlib',
         'to_plot.size': (15, 10)
     }
 )
